/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_P6Xmw5kT);
  numBytes += sLine_init(&sLine_8rlFkSIv);
  numBytes += sTabhead_init(&sTabhead_5iG1uN95, &hTable_BB06tZPb);
  numBytes += sTabread_init(&sTabread_e1hIlKHd, &hTable_BB06tZPb, false);
  numBytes += sTabread_init(&sTabread_q1MxsTXW, &hTable_BB06tZPb, false);
  numBytes += sLine_init(&sLine_t5yYSZX0);
  numBytes += sLine_init(&sLine_3feeeNZq);
  numBytes += sLine_init(&sLine_mM2tHVYt);
  numBytes += sTabhead_init(&sTabhead_zNTIP7vM, &hTable_6pVpzoIu);
  numBytes += sTabread_init(&sTabread_5bLuJhQv, &hTable_6pVpzoIu, false);
  numBytes += sTabread_init(&sTabread_Bu1ig3Lu, &hTable_6pVpzoIu, false);
  numBytes += sLine_init(&sLine_XnUPqK5y);
  numBytes += sTabwrite_init(&sTabwrite_eHfr6ZU5, &hTable_BB06tZPb);
  numBytes += sTabwrite_init(&sTabwrite_TSMxs4ys, &hTable_6pVpzoIu);
  numBytes += sRPole_init(&sRPole_dfGKiOo7);
  numBytes += sRPole_init(&sRPole_evEXuCgk);
  numBytes += sRPole_init(&sRPole_V5OffHk3);
  numBytes += sDel1_init(&sDel1_Xe5quKp4);
  numBytes += sLine_init(&sLine_EEdbL3tq);
  numBytes += sLine_init(&sLine_vT9UpiUx);
  numBytes += sRPole_init(&sRPole_Jd0E9N8b);
  numBytes += sRPole_init(&sRPole_tjOEaJ3G);
  numBytes += sRPole_init(&sRPole_AjKIZbdK);
  numBytes += sDel1_init(&sDel1_XXqAon1Q);
  numBytes += sLine_init(&sLine_DoRYfXwo);
  numBytes += sLine_init(&sLine_jP3b8OFk);
  numBytes += sLine_init(&sLine_fMr2Nt1z);
  numBytes += sLine_init(&sLine_jBeJUZqm);
  numBytes += cVar_init_f(&cVar_CnX0FvFe, 0.0f);
  numBytes += cVar_init_f(&cVar_itDJ85Xs, 0.0f);
  numBytes += cVar_init_f(&cVar_QUnsX4QY, 0.0f);
  numBytes += cVar_init_f(&cVar_qkoBcKeX, 0.0f);
  numBytes += cSlice_init(&cSlice_xGe4dJ3a, 1, -1);
  numBytes += cVar_init_f(&cVar_vV64zuXZ, 0.5f);
  numBytes += cSlice_init(&cSlice_VGglBubi, 1, -1);
  numBytes += cVar_init_f(&cVar_2GTDjq71, 0.2f);
  numBytes += cSlice_init(&cSlice_lEDi2eU8, 1, -1);
  numBytes += cVar_init_f(&cVar_MGqEoUvo, 500.0f);
  numBytes += cSlice_init(&cSlice_8N59HhNH, 1, -1);
  numBytes += cVar_init_f(&cVar_KSwTgx9h, 0.25f);
  numBytes += cDelay_init(this, &cDelay_txzv7bIH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ti61ozbp, 0.0f);
  numBytes += hTable_init(&hTable_BB06tZPb, 256);
  numBytes += cDelay_init(this, &cDelay_SCRLdL0j, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zBLTRH7B, 0.0f);
  numBytes += hTable_init(&hTable_6pVpzoIu, 256);
  numBytes += cVar_init_f(&cVar_EBLMYYc1, 8000.0f);
  numBytes += cBinop_init(&cBinop_k8ihqkro, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kGifoAnB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eNb62BcZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_cNa3UFfl, 8000.0f);
  numBytes += cBinop_init(&cBinop_DuCBE2Bm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_L3CoMR6d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KCNSQpIm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_teV9yIeE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ND4HRxag, 300.0f);
  numBytes += cBinop_init(&cBinop_K64tNYVY, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_X8ZdtCsG, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_nLsECndV, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_87E3lR0q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hG2WqC2D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pxks6fua, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_dKkUtCq3, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_UDhg7iLn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eW1ZZyWY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bSajFJ41, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_zBCY8rPZ, 8000.0f);
  numBytes += cBinop_init(&cBinop_P2CYp0Yc, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_sppxnNPq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8SzBXBK0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_v2XpdlIM, 8000.0f);
  numBytes += cBinop_init(&cBinop_w2V4mByg, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_2kmMMIBq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wjGRAVNq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G4I6sMDc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_C9b9xnX1, 300.0f);
  numBytes += cBinop_init(&cBinop_3J6NIu98, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Bj3sTZ2q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_F99vJnDi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4iPliWGO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hV7pbVFA, 1.0f);
  numBytes += cIf_init(&cIf_dFNXwjtu, false);
  numBytes += cIf_init(&cIf_0u34hFGK, false);
  numBytes += cVar_init_f(&cVar_0BUTM17g, 0.0f);
  numBytes += cVar_init_f(&cVar_syFIsLDH, 0.0f);
  numBytes += cVar_init_f(&cVar_kj0upnvD, 60000.0f);
  numBytes += cVar_init_f(&cVar_f0TiiCQX, 500.0f);
  numBytes += cSlice_init(&cSlice_a3dDXJ5S, 1, -1);
  numBytes += cSlice_init(&cSlice_C0YHXubG, 1, -1);
  numBytes += cVar_init_f(&cVar_e47mc4ft, 0.0f);
  numBytes += cIf_init(&cIf_SHCW3bRW, false);
  numBytes += cBinop_init(&cBinop_CED3OU5X, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_bUXrbJLF, 120.0f);
  numBytes += cBinop_init(&cBinop_rWeUD8sU, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_cNItvQ4S, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_BB06tZPb);
  hTable_free(&hTable_6pVpzoIu);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_BB06tZPb; // del-1011-delayL
    case 0xF057CB49: return &hTable_6pVpzoIu; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vnw6sBl4_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6BlLpGut_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jet3i864_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dgTwqCX0_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_X5IYWlNp_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fYqA30kK_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yzsmfH1d_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wQYHSQfO_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CKEdIceZ_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iFZxdtSX_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8O5jKGZP_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0nRmbMXn_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_CnX0FvFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6BZkkZOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_itDJ85Xs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8OPZi7q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_QUnsX4QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xen2kG1K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_qkoBcKeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GD5zVR9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_rElCMcwk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xGe4dJ3a, 0, m, &cSlice_xGe4dJ3a_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_xGe4dJ3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YEUOPddq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YEUOPddq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_vV64zuXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YEUOPddq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_YEUOPddq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CKEdIceZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_7Lt6mk58_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VGglBubi, 0, m, &cSlice_VGglBubi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MNUTX7nO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_VGglBubi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VScOLQdL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VScOLQdL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_2GTDjq71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VScOLQdL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_VScOLQdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yzsmfH1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_MaYUVoKb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lEDi2eU8, 0, m, &cSlice_lEDi2eU8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rElCMcwk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_lEDi2eU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M5zGqcj5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M5zGqcj5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_MGqEoUvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M5zGqcj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_M5zGqcj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iFZxdtSX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_0bdNtIQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dvyDh0YE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dvyDh0YE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_OfPB9eRB_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_895vNVuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uyJeZTO1_sendMessage(_c, 0, m);
  cMsg_w6IgVg2i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_RYssBIsx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HKSciSed_sendMessage(_c, 0, m);
  cMsg_M4Zmt20q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_OfPB9eRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_68iKxw5e_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_68iKxw5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N0H1QOX4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gzQWTQ1r_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_gzQWTQ1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJPH02Y5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_N0H1QOX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9BOux1Y7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9BOux1Y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_w9CYTFML_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_CJPH02Y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DWxLVITm_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_DWxLVITm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1i02nxXo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_w9CYTFML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_895vNVuT_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1i02nxXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_RYssBIsx_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mhcvn7Ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_TdclAd9o_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TdclAd9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_QjSNcPlk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QjSNcPlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eJL7vlLQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_eJL7vlLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bKWohZhn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ogZ2se4H_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_bKWohZhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_swj5RAyt_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_ogZ2se4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jF8MECZn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_swj5RAyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BR6P2RJ1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jF8MECZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rFfjvfMQ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rFfjvfMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jmKHoVUA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jmKHoVUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Edt9RANe_sendMessage(_c, 0, m);
  cMsg_TSeeipa6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_BR6P2RJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8FdMoB3L_sendMessage(_c, 0, m);
  cMsg_W1PRkzeZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_MNUTX7nO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8N59HhNH, 0, m, &cSlice_8N59HhNH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MaYUVoKb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_8N59HhNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6mjHDxRP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6mjHDxRP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_KSwTgx9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6mjHDxRP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_6mjHDxRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wQYHSQfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_8b3Ze1eY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9MZSrUbp_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_9MZSrUbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ur1fFe8y_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_txzv7bIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_txzv7bIH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ti61ozbp, 0, m, &cDelay_ti61ozbp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_txzv7bIH, 0, m, &cDelay_txzv7bIH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eHfr6ZU5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_ti61ozbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ti61ozbp, m);
  cMsg_nyW0mPyK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_v2afllYY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_98ODdMCX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_E1cD4y1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HjGTE5Ok_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_BB06tZPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHfweso8_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_txzv7bIH, 2, m, &cDelay_txzv7bIH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PApl7rnm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_HjGTE5Ok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_BB06tZPb, 0, m, &hTable_BB06tZPb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ur1fFe8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_E1cD4y1D_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_nyW0mPyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_BB06tZPb, 0, m, &hTable_BB06tZPb_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_PApl7rnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_txzv7bIH, 0, m, &cDelay_txzv7bIH_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_EHfweso8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ti61ozbp, 2, m, &cDelay_ti61ozbp_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_98ODdMCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eHfr6ZU5, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_te7TkPAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3wChbpnl_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_3wChbpnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Cyc7SWwX_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_SCRLdL0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SCRLdL0j, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zBLTRH7B, 0, m, &cDelay_zBLTRH7B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SCRLdL0j, 0, m, &cDelay_SCRLdL0j_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TSMxs4ys, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_zBLTRH7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zBLTRH7B, m);
  cMsg_E8I0b2t0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_9gJafpSO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_hMQ1j1Qr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_88WydPzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SNHSz335_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_6pVpzoIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JoS3dbjn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SCRLdL0j, 2, m, &cDelay_SCRLdL0j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7aRVM2DY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SNHSz335_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6pVpzoIu, 0, m, &hTable_6pVpzoIu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Cyc7SWwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_88WydPzP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_E8I0b2t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6pVpzoIu, 0, m, &hTable_6pVpzoIu_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7aRVM2DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SCRLdL0j, 0, m, &cDelay_SCRLdL0j_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JoS3dbjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zBLTRH7B, 2, m, &cDelay_zBLTRH7B_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hMQ1j1Qr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TSMxs4ys, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_EBLMYYc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8ihqkro, HV_BINOP_MULTIPLY, 0, m, &cBinop_k8ihqkro_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4EwFH06L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_OBSMZhDP_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_OBSMZhDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cSYwodbj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_k8ihqkro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OugBFqby_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ELqvhv2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8ihqkro, HV_BINOP_MULTIPLY, 1, m, &cBinop_k8ihqkro_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_cSYwodbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ELqvhv2b_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_OugBFqby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_J5QgW62D_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_J5QgW62D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eIr7WX4P_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_eNb62BcZ, m);
}

void Heavy_WSTD_DLAY::cBinop_eIr7WX4P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kGifoAnB, m);
}

void Heavy_WSTD_DLAY::cVar_cNa3UFfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuCBE2Bm, HV_BINOP_MULTIPLY, 0, m, &cBinop_DuCBE2Bm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_69CWFPWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jROdlKss_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_jROdlKss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y74yvean_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_DuCBE2Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Ij763sqP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_kz1WzfAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DuCBE2Bm, HV_BINOP_MULTIPLY, 1, m, &cBinop_DuCBE2Bm_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_y74yvean_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kz1WzfAW_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Ij763sqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fnVuxFMz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fnVuxFMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_OaRU7jX5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_KCNSQpIm, m);
}

void Heavy_WSTD_DLAY::cBinop_OaRU7jX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_L3CoMR6d, m);
}

void Heavy_WSTD_DLAY::cBinop_zYSR7K95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_wix2d3At_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wix2d3At_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MWbRWvnF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YIs4w1bF_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_ND4HRxag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_3V7562ix_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XSrmfLRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FS0l996Y_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_FS0l996Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K64tNYVY, HV_BINOP_DIVIDE, 1, m, &cBinop_K64tNYVY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MWbRWvnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9LMZhLmb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9LMZhLmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_X8ZdtCsG, m);
}

void Heavy_WSTD_DLAY::cMsg_2pRiBtTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BK6jX7z5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_BK6jX7z5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_zYSR7K95_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YIs4w1bF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_teV9yIeE, m);
}

void Heavy_WSTD_DLAY::cBinop_3V7562ix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Qzvlydhj_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Qzvlydhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K64tNYVY, HV_BINOP_DIVIDE, 0, m, &cBinop_K64tNYVY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_K64tNYVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2pRiBtTU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_3abDFYDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CCZj2iVR_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_CCZj2iVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PbrSOchU_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_nLsECndV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bYWm3Cp8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_ph4Ro6Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_QbwxYSZ9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_87E3lR0q, m);
}

void Heavy_WSTD_DLAY::cBinop_PbrSOchU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hG2WqC2D, m);
}

void Heavy_WSTD_DLAY::cMsg_bYWm3Cp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ph4Ro6Vu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QbwxYSZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pxks6fua, m);
}

void Heavy_WSTD_DLAY::cMsg_WFHeZhVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xDnnl41l_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_xDnnl41l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Uywfibly_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_dKkUtCq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jEw2ZWnz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_0xtOZB1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qS74NNQe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UDhg7iLn, m);
}

void Heavy_WSTD_DLAY::cBinop_Uywfibly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eW1ZZyWY, m);
}

void Heavy_WSTD_DLAY::cMsg_jEw2ZWnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0xtOZB1Z_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qS74NNQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bSajFJ41, m);
}

void Heavy_WSTD_DLAY::cVar_zBCY8rPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2CYp0Yc, HV_BINOP_MULTIPLY, 0, m, &cBinop_P2CYp0Yc_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_pqpPoDT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lkHinYzT_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_lkHinYzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2XQjbUNs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_P2CYp0Yc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_h14udtUb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_p1EbND73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P2CYp0Yc, HV_BINOP_MULTIPLY, 1, m, &cBinop_P2CYp0Yc_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2XQjbUNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_p1EbND73_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_h14udtUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_3krblfCt_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3krblfCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_writFft3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_8SzBXBK0, m);
}

void Heavy_WSTD_DLAY::cBinop_writFft3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_sppxnNPq, m);
}

void Heavy_WSTD_DLAY::cVar_v2XpdlIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2V4mByg, HV_BINOP_MULTIPLY, 0, m, &cBinop_w2V4mByg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_E6N8axOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FuqxzmE9_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_FuqxzmE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y5s0JTtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_w2V4mByg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ahMiTjst_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_biZh23nU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w2V4mByg, HV_BINOP_MULTIPLY, 1, m, &cBinop_w2V4mByg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Y5s0JTtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_biZh23nU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ahMiTjst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mx3GrDcp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mx3GrDcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_z9JwDxr3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wjGRAVNq, m);
}

void Heavy_WSTD_DLAY::cBinop_z9JwDxr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2kmMMIBq, m);
}

void Heavy_WSTD_DLAY::cBinop_IU6RWyKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dEOwydTR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dEOwydTR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pIVaLgRI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fnWKINVa_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_C9b9xnX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_wbo5A3Jt_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_a4CEiWW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bc6raD7R_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_bc6raD7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3J6NIu98, HV_BINOP_DIVIDE, 1, m, &cBinop_3J6NIu98_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pIVaLgRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7NyZQ6xK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7NyZQ6xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Bj3sTZ2q, m);
}

void Heavy_WSTD_DLAY::cMsg_QAUcBvwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0aw6y8Gd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0aw6y8Gd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_IU6RWyKI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fnWKINVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_G4I6sMDc, m);
}

void Heavy_WSTD_DLAY::cBinop_wbo5A3Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_xh9ij0DG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xh9ij0DG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3J6NIu98, HV_BINOP_DIVIDE, 0, m, &cBinop_3J6NIu98_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3J6NIu98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QAUcBvwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_uyJeZTO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t5yYSZX0, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HKSciSed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P6Xmw5kT, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_M4Zmt20q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3feeeNZq, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_w6IgVg2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XnUPqK5y, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_W1PRkzeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jP3b8OFk, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Edt9RANe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vT9UpiUx, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_8FdMoB3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jBeJUZqm, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_TSeeipa6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fMr2Nt1z, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Lkhz4ZFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8rlFkSIv, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_ys8fq2Hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mM2tHVYt, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_x32vFNw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EEdbL3tq, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_62dkFDZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DoRYfXwo, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_hV7pbVFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JQ4U3giT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0dJbGZ5G_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bjzuimHC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JQ4U3giT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hV7pbVFA, 1, m, &cVar_hV7pbVFA_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_dFNXwjtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_itDJ85Xs, 0, m, &cVar_itDJ85Xs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_0u34hFGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_itDJ85Xs, 0, m, &cVar_itDJ85Xs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_0BUTM17g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0u34hFGK, 0, m, &cIf_0u34hFGK_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_syFIsLDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dFNXwjtu, 0, m, &cIf_dFNXwjtu_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_kj0upnvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWeUD8sU, HV_BINOP_DIVIDE, 0, m, &cBinop_rWeUD8sU_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_f0TiiCQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cNItvQ4S, HV_BINOP_MULTIPLY, 1, m, &cBinop_cNItvQ4S_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_ZPItrYCi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a3dDXJ5S, 0, m, &cSlice_a3dDXJ5S_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C0YHXubG, 0, m, &cSlice_C0YHXubG_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JLJdE21j_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EXAWtLLQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_a3dDXJ5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_e47mc4ft, 0, m, &cVar_e47mc4ft_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_e47mc4ft, 0, m, &cVar_e47mc4ft_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_C0YHXubG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CED3OU5X, HV_BINOP_NEQ, 1, m, &cBinop_CED3OU5X_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_e47mc4ft, 1, m, &cVar_e47mc4ft_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_CED3OU5X, HV_BINOP_NEQ, 1, m, &cBinop_CED3OU5X_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_e47mc4ft, 1, m, &cVar_e47mc4ft_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_e47mc4ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_1RAulOdR_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_SHCW3bRW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M1aYYeeR_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BNc9mF5t_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_BNc9mF5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e47mc4ft, 0, m, &cVar_e47mc4ft_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_M1aYYeeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CED3OU5X, HV_BINOP_NEQ, 1, m, &cBinop_CED3OU5X_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CED3OU5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SHCW3bRW, 1, m, &cIf_SHCW3bRW_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_EXAWtLLQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SHCW3bRW, 0, m, &cIf_SHCW3bRW_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JLJdE21j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CED3OU5X, HV_BINOP_NEQ, 0, m, &cBinop_CED3OU5X_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_bUXrbJLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tRHxIKqt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pBLQv9is_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_1tzJFnAx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZkHaO1rx_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NLmeZk1R_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9IMsCDRh_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TpuSMs3L_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LaSb5iqE_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JO4yM9iJ_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K19FBQOi_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6yzYKyB1_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dqCKhqcV_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JhIy7J6e_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7xAO7Woa_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CcqVNqMM_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8PoSYXBE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_ZkHaO1rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IoBFsEAg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_NLmeZk1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qCIAqccG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_9IMsCDRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zAdQHrxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_TpuSMs3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3izf0dLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_LaSb5iqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bTmPbG5w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_JO4yM9iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_obK9g8oa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_K19FBQOi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UdLUTSKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_6yzYKyB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6dIdplAD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_dqCKhqcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pThpSmNE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_JhIy7J6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_llFAQCoC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_7xAO7Woa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwGMk8Ln_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CcqVNqMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aOrUOPds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_8PoSYXBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ds1tpoSQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_rWeUD8sU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cNItvQ4S, HV_BINOP_MULTIPLY, 0, m, &cBinop_cNItvQ4S_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_cNItvQ4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZPItrYCi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_pBLQv9is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kj0upnvD, 0, m, &cVar_kj0upnvD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f0TiiCQX, 0, m, &cVar_f0TiiCQX_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_tRHxIKqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rWeUD8sU, HV_BINOP_DIVIDE, 1, m, &cBinop_rWeUD8sU_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_ZBBrXFZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kj0upnvD, 0, m, &cVar_kj0upnvD_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_VSTUhd3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0TiiCQX, 0, m, &cVar_f0TiiCQX_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IoBFsEAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_qCIAqccG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_zAdQHrxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3izf0dLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bTmPbG5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_obK9g8oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UdLUTSKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6dIdplAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_pThpSmNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_llFAQCoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bwGMk8Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_aOrUOPds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Ds1tpoSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VSTUhd3x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBBrXFZQ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GD5zVR9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7Lt6mk58_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_6BZkkZOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7Lt6mk58_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_CKK7S8ZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qkoBcKeX, 0, m, &cVar_qkoBcKeX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wtGiuzna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CnX0FvFe, 0, m, &cVar_CnX0FvFe_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wCTbAxLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QUnsX4QY, 0, m, &cVar_QUnsX4QY_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_u8OPZi7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7Lt6mk58_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_xen2kG1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_7Lt6mk58_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_1RAulOdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_syFIsLDH, 0, m, &cVar_syFIsLDH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bjzuimHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qmoxGZi0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hHFz1X7F_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0dJbGZ5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RTLsFL0c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zVdJqJj_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_9zVdJqJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0BUTM17g, 0, m, &cVar_0BUTM17g_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_RTLsFL0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0u34hFGK, 1, m, &cIf_0u34hFGK_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_qmoxGZi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dFNXwjtu, 1, m, &cIf_dFNXwjtu_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_hHFz1X7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_syFIsLDH, 0, m, &cVar_syFIsLDH_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_Jet3i864_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_CKK7S8ZF_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_6BlLpGut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wtGiuzna_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_vnw6sBl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wCTbAxLJ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_X5IYWlNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0BUTM17g, 0, m, &cVar_0BUTM17g_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_iFZxdtSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lkhz4ZFq_sendMessage(_c, 0, m);
  cMsg_ys8fq2Hu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_wQYHSQfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x32vFNw2_sendMessage(_c, 0, m);
  cMsg_62dkFDZK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_CKEdIceZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0bdNtIQt_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_0nRmbMXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vV64zuXZ, 0, m, &cVar_vV64zuXZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2GTDjq71, 0, m, &cVar_2GTDjq71_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MGqEoUvo, 0, m, &cVar_MGqEoUvo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KSwTgx9h, 0, m, &cVar_KSwTgx9h_sendMessage);
  cMsg_8b3Ze1eY_sendMessage(_c, 0, m);
  cMsg_te7TkPAH_sendMessage(_c, 0, m);
  cMsg_4EwFH06L_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EBLMYYc1, 0, m, &cVar_EBLMYYc1_sendMessage);
  cMsg_69CWFPWy_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_cNa3UFfl, 0, m, &cVar_cNa3UFfl_sendMessage);
  cMsg_XSrmfLRw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ND4HRxag, 0, m, &cVar_ND4HRxag_sendMessage);
  cMsg_pqpPoDT3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zBCY8rPZ, 0, m, &cVar_zBCY8rPZ_sendMessage);
  cMsg_E6N8axOD_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_v2XpdlIM, 0, m, &cVar_v2XpdlIM_sendMessage);
  cMsg_a4CEiWW0_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_C9b9xnX1, 0, m, &cVar_C9b9xnX1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nLsECndV, 0, m, &cVar_nLsECndV_sendMessage);
  cMsg_3abDFYDO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dKkUtCq3, 0, m, &cVar_dKkUtCq3_sendMessage);
  cMsg_WFHeZhVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_yzsmfH1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mhcvn7Ro_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_dgTwqCX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hV7pbVFA, 0, m, &cVar_hV7pbVFA_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_8O5jKGZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bUXrbJLF, 0, m, &cVar_bUXrbJLF_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_fYqA30kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1tzJFnAx_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_P6Xmw5kT, VOf(Bf0));
    __hv_line_f(&sLine_8rlFkSIv, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_5iG1uN95, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_hG2WqC2D, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_pxks6fua, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_87E3lR0q, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_e1hIlKHd, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_q1MxsTXW, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_t5yYSZX0, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_3feeeNZq, VOf(Bf0));
    __hv_line_f(&sLine_mM2tHVYt, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_zNTIP7vM, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_eW1ZZyWY, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_bSajFJ41, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_UDhg7iLn, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_5bLuJhQv, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_Bu1ig3Lu, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_XnUPqK5y, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_F99vJnDi, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_eHfr6ZU5, VIf(Bf0));
    __hv_varread_f(&sVarf_4iPliWGO, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_TSMxs4ys, VIf(Bf0));
    __hv_varread_f(&sVarf_eNb62BcZ, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_kGifoAnB, VOf(Bf1));
    __hv_rpole_f(&sRPole_dfGKiOo7, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_KCNSQpIm, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_L3CoMR6d, VOf(Bf1));
    __hv_rpole_f(&sRPole_evEXuCgk, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_teV9yIeE, VOf(Bf0));
    __hv_rpole_f(&sRPole_V5OffHk3, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Xe5quKp4, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_X8ZdtCsG, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_EEdbL3tq, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_vT9UpiUx, VOf(Bf0));
    __hv_varread_f(&sVarf_8SzBXBK0, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_sppxnNPq, VOf(Bf4));
    __hv_rpole_f(&sRPole_Jd0E9N8b, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wjGRAVNq, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_2kmMMIBq, VOf(Bf4));
    __hv_rpole_f(&sRPole_tjOEaJ3G, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_G4I6sMDc, VOf(Bf6));
    __hv_rpole_f(&sRPole_AjKIZbdK, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_XXqAon1Q, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Bj3sTZ2q, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_DoRYfXwo, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_jP3b8OFk, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_F99vJnDi, VIf(Bf6));
    __hv_line_f(&sLine_fMr2Nt1z, VOf(Bf6));
    __hv_line_f(&sLine_jBeJUZqm, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_4iPliWGO, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
