/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvControlSlice.h"
#include "HvControlBinop.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvSignalVar.h"
#include "HvSignalTabread.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvSignalDel1.h"
#include "HvControlVar.h"
#include "HvSignalLine.h"
#include "HvControlSystem.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_CnX0FvFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_itDJ85Xs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QUnsX4QY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qkoBcKeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rElCMcwk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xGe4dJ3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vV64zuXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YEUOPddq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7Lt6mk58_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_VGglBubi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2GTDjq71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VScOLQdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MaYUVoKb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_lEDi2eU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MGqEoUvo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_M5zGqcj5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0bdNtIQt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dvyDh0YE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_895vNVuT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RYssBIsx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OfPB9eRB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_68iKxw5e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gzQWTQ1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N0H1QOX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9BOux1Y7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJPH02Y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DWxLVITm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w9CYTFML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1i02nxXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mhcvn7Ro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TdclAd9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QjSNcPlk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJL7vlLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bKWohZhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ogZ2se4H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_swj5RAyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jF8MECZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rFfjvfMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jmKHoVUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BR6P2RJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MNUTX7nO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8N59HhNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KSwTgx9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6mjHDxRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8b3Ze1eY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9MZSrUbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_txzv7bIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ti61ozbp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v2afllYY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_E1cD4y1D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_BB06tZPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HjGTE5Ok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ur1fFe8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nyW0mPyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PApl7rnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EHfweso8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_98ODdMCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_te7TkPAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3wChbpnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SCRLdL0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zBLTRH7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9gJafpSO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_88WydPzP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_6pVpzoIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SNHSz335_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cyc7SWwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E8I0b2t0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7aRVM2DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JoS3dbjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hMQ1j1Qr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EBLMYYc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4EwFH06L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_OBSMZhDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8ihqkro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ELqvhv2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cSYwodbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OugBFqby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J5QgW62D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eIr7WX4P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cNa3UFfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_69CWFPWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jROdlKss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DuCBE2Bm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kz1WzfAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y74yvean_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ij763sqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fnVuxFMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OaRU7jX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zYSR7K95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wix2d3At_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ND4HRxag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XSrmfLRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FS0l996Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MWbRWvnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9LMZhLmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2pRiBtTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BK6jX7z5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YIs4w1bF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3V7562ix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qzvlydhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K64tNYVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3abDFYDO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CCZj2iVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nLsECndV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ph4Ro6Vu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PbrSOchU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bYWm3Cp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QbwxYSZ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WFHeZhVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xDnnl41l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dKkUtCq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0xtOZB1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uywfibly_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jEw2ZWnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qS74NNQe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zBCY8rPZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pqpPoDT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lkHinYzT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P2CYp0Yc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p1EbND73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2XQjbUNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h14udtUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3krblfCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_writFft3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v2XpdlIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6N8axOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FuqxzmE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w2V4mByg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_biZh23nU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y5s0JTtR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ahMiTjst_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mx3GrDcp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z9JwDxr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IU6RWyKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dEOwydTR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C9b9xnX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a4CEiWW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bc6raD7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pIVaLgRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7NyZQ6xK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QAUcBvwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0aw6y8Gd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fnWKINVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wbo5A3Jt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xh9ij0DG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3J6NIu98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uyJeZTO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HKSciSed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M4Zmt20q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w6IgVg2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W1PRkzeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Edt9RANe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8FdMoB3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TSeeipa6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lkhz4ZFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ys8fq2Hu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x32vFNw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_62dkFDZK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hV7pbVFA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JQ4U3giT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dFNXwjtu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0u34hFGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0BUTM17g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_syFIsLDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kj0upnvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f0TiiCQX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZPItrYCi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_a3dDXJ5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_C0YHXubG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_e47mc4ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SHCW3bRW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BNc9mF5t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M1aYYeeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CED3OU5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EXAWtLLQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JLJdE21j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bUXrbJLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1tzJFnAx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ZkHaO1rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NLmeZk1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9IMsCDRh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TpuSMs3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LaSb5iqE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JO4yM9iJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K19FBQOi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6yzYKyB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dqCKhqcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JhIy7J6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7xAO7Woa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CcqVNqMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8PoSYXBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rWeUD8sU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cNItvQ4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pBLQv9is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tRHxIKqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZBBrXFZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VSTUhd3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IoBFsEAg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qCIAqccG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zAdQHrxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3izf0dLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bTmPbG5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_obK9g8oa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UdLUTSKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6dIdplAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pThpSmNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_llFAQCoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bwGMk8Ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aOrUOPds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ds1tpoSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GD5zVR9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6BZkkZOM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CKK7S8ZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wtGiuzna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCTbAxLJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u8OPZi7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xen2kG1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1RAulOdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bjzuimHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0dJbGZ5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9zVdJqJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RTLsFL0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qmoxGZi0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hHFz1X7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Jet3i864_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6BlLpGut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vnw6sBl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_X5IYWlNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iFZxdtSX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wQYHSQfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CKEdIceZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0nRmbMXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yzsmfH1d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dgTwqCX0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8O5jKGZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fYqA30kK_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_P6Xmw5kT;
  SignalLine sLine_8rlFkSIv;
  SignalTabhead sTabhead_5iG1uN95;
  SignalTabread sTabread_e1hIlKHd;
  SignalTabread sTabread_q1MxsTXW;
  SignalLine sLine_t5yYSZX0;
  SignalLine sLine_3feeeNZq;
  SignalLine sLine_mM2tHVYt;
  SignalTabhead sTabhead_zNTIP7vM;
  SignalTabread sTabread_5bLuJhQv;
  SignalTabread sTabread_Bu1ig3Lu;
  SignalLine sLine_XnUPqK5y;
  SignalTabwrite sTabwrite_eHfr6ZU5;
  SignalTabwrite sTabwrite_TSMxs4ys;
  SignalRPole sRPole_dfGKiOo7;
  SignalRPole sRPole_evEXuCgk;
  SignalRPole sRPole_V5OffHk3;
  SignalDel1 sDel1_Xe5quKp4;
  SignalLine sLine_EEdbL3tq;
  SignalLine sLine_vT9UpiUx;
  SignalRPole sRPole_Jd0E9N8b;
  SignalRPole sRPole_tjOEaJ3G;
  SignalRPole sRPole_AjKIZbdK;
  SignalDel1 sDel1_XXqAon1Q;
  SignalLine sLine_DoRYfXwo;
  SignalLine sLine_jP3b8OFk;
  SignalLine sLine_fMr2Nt1z;
  SignalLine sLine_jBeJUZqm;
  ControlVar cVar_CnX0FvFe;
  ControlVar cVar_itDJ85Xs;
  ControlVar cVar_QUnsX4QY;
  ControlVar cVar_qkoBcKeX;
  ControlSlice cSlice_xGe4dJ3a;
  ControlVar cVar_vV64zuXZ;
  ControlSlice cSlice_VGglBubi;
  ControlVar cVar_2GTDjq71;
  ControlSlice cSlice_lEDi2eU8;
  ControlVar cVar_MGqEoUvo;
  ControlBinop cBinop_0bdNtIQt;
  ControlBinop cBinop_dvyDh0YE;
  ControlBinop cBinop_OfPB9eRB;
  ControlBinop cBinop_68iKxw5e;
  ControlBinop cBinop_9BOux1Y7;
  ControlBinop cBinop_DWxLVITm;
  ControlBinop cBinop_w9CYTFML;
  ControlBinop cBinop_1i02nxXo;
  ControlBinop cBinop_mhcvn7Ro;
  ControlBinop cBinop_TdclAd9o;
  ControlBinop cBinop_QjSNcPlk;
  ControlBinop cBinop_eJL7vlLQ;
  ControlBinop cBinop_swj5RAyt;
  ControlBinop cBinop_rFfjvfMQ;
  ControlBinop cBinop_jmKHoVUA;
  ControlBinop cBinop_BR6P2RJ1;
  ControlSlice cSlice_8N59HhNH;
  ControlVar cVar_KSwTgx9h;
  ControlDelay cDelay_txzv7bIH;
  ControlDelay cDelay_ti61ozbp;
  ControlBinop cBinop_E1cD4y1D;
  HvTable hTable_BB06tZPb;
  ControlBinop cBinop_ur1fFe8y;
  ControlDelay cDelay_SCRLdL0j;
  ControlDelay cDelay_zBLTRH7B;
  ControlBinop cBinop_88WydPzP;
  HvTable hTable_6pVpzoIu;
  ControlBinop cBinop_Cyc7SWwX;
  ControlVar cVar_EBLMYYc1;
  ControlBinop cBinop_k8ihqkro;
  ControlBinop cBinop_ELqvhv2b;
  SignalVarf sVarf_kGifoAnB;
  ControlBinop cBinop_OugBFqby;
  ControlBinop cBinop_J5QgW62D;
  ControlBinop cBinop_eIr7WX4P;
  SignalVarf sVarf_eNb62BcZ;
  ControlVar cVar_cNa3UFfl;
  ControlBinop cBinop_DuCBE2Bm;
  ControlBinop cBinop_kz1WzfAW;
  SignalVarf sVarf_L3CoMR6d;
  ControlBinop cBinop_Ij763sqP;
  ControlBinop cBinop_fnVuxFMz;
  ControlBinop cBinop_OaRU7jX5;
  SignalVarf sVarf_KCNSQpIm;
  ControlBinop cBinop_zYSR7K95;
  ControlBinop cBinop_wix2d3At;
  SignalVarf sVarf_teV9yIeE;
  ControlVar cVar_ND4HRxag;
  ControlBinop cBinop_MWbRWvnF;
  ControlBinop cBinop_9LMZhLmb;
  ControlBinop cBinop_BK6jX7z5;
  ControlBinop cBinop_YIs4w1bF;
  ControlBinop cBinop_3V7562ix;
  ControlBinop cBinop_Qzvlydhj;
  ControlBinop cBinop_K64tNYVY;
  SignalVarf sVarf_X8ZdtCsG;
  ControlVar cVar_nLsECndV;
  ControlBinop cBinop_PbrSOchU;
  ControlBinop cBinop_QbwxYSZ9;
  SignalVarf sVarf_87E3lR0q;
  SignalVarf sVarf_hG2WqC2D;
  SignalVarf sVarf_pxks6fua;
  ControlVar cVar_dKkUtCq3;
  ControlBinop cBinop_Uywfibly;
  ControlBinop cBinop_qS74NNQe;
  SignalVarf sVarf_UDhg7iLn;
  SignalVarf sVarf_eW1ZZyWY;
  SignalVarf sVarf_bSajFJ41;
  ControlVar cVar_zBCY8rPZ;
  ControlBinop cBinop_P2CYp0Yc;
  ControlBinop cBinop_p1EbND73;
  SignalVarf sVarf_sppxnNPq;
  ControlBinop cBinop_h14udtUb;
  ControlBinop cBinop_3krblfCt;
  ControlBinop cBinop_writFft3;
  SignalVarf sVarf_8SzBXBK0;
  ControlVar cVar_v2XpdlIM;
  ControlBinop cBinop_w2V4mByg;
  ControlBinop cBinop_biZh23nU;
  SignalVarf sVarf_2kmMMIBq;
  ControlBinop cBinop_ahMiTjst;
  ControlBinop cBinop_mx3GrDcp;
  ControlBinop cBinop_z9JwDxr3;
  SignalVarf sVarf_wjGRAVNq;
  ControlBinop cBinop_IU6RWyKI;
  ControlBinop cBinop_dEOwydTR;
  SignalVarf sVarf_G4I6sMDc;
  ControlVar cVar_C9b9xnX1;
  ControlBinop cBinop_pIVaLgRI;
  ControlBinop cBinop_7NyZQ6xK;
  ControlBinop cBinop_0aw6y8Gd;
  ControlBinop cBinop_fnWKINVa;
  ControlBinop cBinop_wbo5A3Jt;
  ControlBinop cBinop_xh9ij0DG;
  ControlBinop cBinop_3J6NIu98;
  SignalVarf sVarf_Bj3sTZ2q;
  SignalVarf sVarf_F99vJnDi;
  SignalVarf sVarf_4iPliWGO;
  ControlVar cVar_hV7pbVFA;
  ControlBinop cBinop_JQ4U3giT;
  ControlIf cIf_dFNXwjtu;
  ControlIf cIf_0u34hFGK;
  ControlVar cVar_0BUTM17g;
  ControlVar cVar_syFIsLDH;
  ControlVar cVar_kj0upnvD;
  ControlVar cVar_f0TiiCQX;
  ControlSlice cSlice_a3dDXJ5S;
  ControlSlice cSlice_C0YHXubG;
  ControlVar cVar_e47mc4ft;
  ControlIf cIf_SHCW3bRW;
  ControlBinop cBinop_CED3OU5X;
  ControlVar cVar_bUXrbJLF;
  ControlBinop cBinop_rWeUD8sU;
  ControlBinop cBinop_cNItvQ4S;
  ControlBinop cBinop_CKK7S8ZF;
  ControlBinop cBinop_wtGiuzna;
  ControlBinop cBinop_wCTbAxLJ;
  ControlBinop cBinop_1RAulOdR;
  ControlBinop cBinop_bjzuimHC;
  ControlBinop cBinop_0dJbGZ5G;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
